:: MAKEPDF.BAT: Windows XP batch script to create PDF files from DVI
:: Usage: 
::	makepdf [options] filename
:: The filename is mandatory and should not include the DVI extension.
:: Options:
::	-t <papersize> select paper size.
::		Possible values a4, letter, b5, a5. For b5 and a5, pages 
::		should be centered on an A4 document size, in the DVI. The b5
::		format is not ISO standard, instead it is 170x240mm in size.
:: 		The paper size argument is case-insensitive.
::		The default paper size is a4.
::	-p optimize for pre-press.
::		Embeds and subsets all fonts, preserves good image quality.
::	-c <complevel> changes the PDF compatibility level.
::		Value should be a legal setting for the -dCompatibilityLevel
::		GhostScript option (e.g., 1.3 or 1.4). 
::		Default 1.4.
::	-f force PDF size.
::		Ensures the PDF size matches the paper size. Should not be 
::		necessary, since the PDF inherits the size set in the PS file.
::	-d delete intermediate PS file (by default, the file is not deleted).
::	-psarg <extraargs> extra arguments for the DVI to PS converter.
::	-pdfarg <extraargs> extra arguments for the PS to PDF converter.
::	-pdfconv <converter> set a custom pdfconverter.
::		Use "-pdfconv ps2pdf" to use the ps2pdf converter. Can also be 
::		used to specify the path to the GhostScript executable, 
::		by setting, e.g., -pdfconv C:\Progra~1\gs\gs8.63\bin\gswin32c
::	-u, /? display brief usage instructions.
::
:: Use quotes around arguments containing delimiters (such as space or =)
:: Instead of <option> <argument>, the syntax <option>=<argument> can also 
:: be used.
:: This script requires GhostScript to be installed on the system. By default,
:: version 8.63 is assumed to be installed, so that the path to gswin32c is
:: set to C:\Progra~1\gs\gs8.63\bin\
:: 
::
:: Version: 1.1
:: Created by Lucian Busoniu on 20 November 2008
:: Updated by Lucian Busoniu on 20 November 2008
:: History:
::	1.1 -- added quoted arguments and case-insensitive paper types

@ECHO OFF
:: All variables are local
SETLOCAL

:: :::::: Default argument values

:: default paper size
SET papersize=a4

:: conversion arguments
SET psargs=-Ppdf -G0
SET pdfargs=
SET complevel=1.4

:: conversion engines
:: dvips is the only option for the psconverter (at least for now)
SET psconverter=dvips
SET pdfconverter=C:\Progra~1\gs\gs8.63\bin\gswin32c

:: other options
:: by default, the PS file is not deleted
SET delps=no
:: it should not be necessary to force the size of the PDF
SET forcepdfsize=no

:: :::::: Process arguments

:ArgLoop
IF "%1"=="-t" (
	:: get the papersize
	SET papersize=%~2
	SHIFT
) ELSE IF "%1"=="-p" (
	:: arrange for high-quality, "preprint" document
	SET pdfargs=%pdfargs% -dPDFSETTINGS=/prepress -dColorImageDownsampleType=/Bicubic -dColorImageDownsampleThreshold=3 -dColorImageResolution=600 -dGrayImageDownsampleType=/Bicubic -dGrayImageDownsampleThreshold=3 -dGrayImageResolution=600 -dMonoImageDownsampleThreshold=3 -dMonoImageDownsampleType=/Bicubic -dMonoImageResolution=2400 -dAutoFilterColorImages=false -dColorImageFilter=/FlateEncode -dGrayImageFilter=/FlateEncode -dAutoFilterGrayImages=false -dMonoImageFilter=/FlateEncode 
) ELSE IF "%1"=="-c" (
	:: change compatibility level
	SET complevel=%~2
	SHIFT
) ELSE IF "%1"=="-f" (
	:: force PDF page size
	SET forcepdfsize=yes
) ELSE IF "%1"=="-psarg" (
    	SET psargs=%psargs% %~2
	SHIFT
) ELSE IF "%1"=="-pdfarg" (
	:: additional ps conversion arguments
	SET pdfargs=%pdfargs% %~2
	SHIFT
) ELSE IF "%1"=="-pdfconv" (
	:: change the pdf converter
	SET pdfconverter=%~2
	SHIFT
) ELSE IF "%1"=="-d" (
	:: set flag to remove the intermediate PS file
	SET delps=yes
) ELSE IF "%1"=="-u" (
	:: display usage
	ECHO Usage: "makepdf [-t <papersize>] [-p] [-c] [-f] [-d] [-psarg <extrapsarg>] [-pdfarg <extrapdfarg>] [-pdfconv <pathtopdfconverter>] [-u] filename"
	GOTO EOF
) ELSE IF "%1"=="/?" (
	:: display usage
	ECHO Usage: "makepdf [-t <papersize>] [-p] [-c] [-f] [-d] [-psarg <extrapsarg>] [-pdfarg <extrapdfarg>] [-pdfconv <pathtopdfconverter>] [-u] filename"
	GOTO EOF
) ELSE GOTO ArgContinue
:: pop the next argument from the list, and repeat
SHIFT
GOTO ArgLoop
:ArgContinue

:: the first unrecognized argument is the file name; the rest of the arguments are ignored
SET filename=%1
IF "%filename%"=="" (
ECHO Error! No filename given. Terminating.
GOTO EOF
)

:: :::::: process paper size
IF /i %papersize%==a4 (
	SET pspaper=-ta4
	IF "%forcepdfsize%"=="yes" SET pdfpaper=-dDEVICEWIDTHPOINTS=595.275591 -dDEVICEHEIGHTPOINTS=841.889764 -dFIXEDMEDIA
) ELSE IF /i %papersize%==letter (
	SET pspaper=-tletter
	IF "%forcepdfsize%"=="yes" SET pdfpaper=-dDEVICEWIDTHPOINTS=612  -dDEVICEHEIGHTPOINTS=792  -dFIXEDMEDIA
) ELSE IF /i %papersize%==b5 (
	SET pspaper=-T170mm,240mm -O-20mm,-28.5mm
	IF "%forcepdfsize%"=="yes" SET pdfpaper=-dDEVICEWIDTHPOINTS=481.889764 -dDEVICEHEIGHTPOINTS=680.314961 -dFIXEDMEDIA
) ELSE IF /i %papersize%==a5 (
	SET pspaper=-T148mm,210mm -O-31mm,-43.5mm 
	IF "%forcepdfsize%"=="yes" SET pdfpaper=-dDEVICEWIDTHPOINTS=419.527559 -dDEVICEHEIGHTPOINTS=595.275591 -dFIXEDMEDIA
) ELSE (
	SET pspaper=
	SET pdfpaper=
	ECHO Warning! Unrecognized paper size [%papersize%]. Setting no paper size.
)

:: :::::: Finalize argument lists, adding also the paper size, input filename, and output filename
SET psargs=%psargs% %pspaper% -o %1.ps %1.dvi
IF "%pdfconverter%"=="ps2pdf" (
	:: finalize arguments in ps2pdf style
	SET pdfargs="%pdfargs% %pdfpaper% -dCompatibilityLevel=%complevel% -dMaxSubsetPct=100 -dSubsetFonts=true -dEmbedAllFonts=true" %1.ps %1.pdf
) ELSE (
	:: finalize arguments in gs style
	SET pdfargs=%pdfargs% %pdfpaper% -dSAFER -dBATCH -dNOPAUSE -sDEVICE=pdfwrite -dCompatibilityLevel=%complevel% -dMaxSubsetPct=100 -dSubsetFonts=true -dEmbedAllFonts=true -sOutputFile=%1.pdf -f %1.ps
)

:: :::::: Run the converters (with echo so that user knows what's going on)
@ECHO ON
%psconverter% %psargs%
%pdfconverter% %pdfargs%%
@ECHO OFF

:: remove the intermediate PS file if set to do so
IF "%delps%"=="yes" del %1.ps

:: debugging output
:: comment the following line to display debugging output
GOTO EndDebug
ECHO papersize=%papersize%
ECHO psconverter=%psconverter%
ECHO psargs=%psargs%
ECHO pdfconverter=%pdfconverter%
ECHO pdfargs=%pdfargs%
:EndDebug

ENDLOCAL
@ECHO ON
:EOF